@@ -10,6 +10,7 @@ from pathlib import Path
 
 # from pprint import pprint as print
 from urllib.parse import urlparse
+from fesenjoon.custom_type import PathType
 
 from google.auth.transport.requests import Request
 from google_auth_oauthlib.flow import InstalledAppFlow
@@ -27,10 +28,20 @@ class Drive:
         "https://www.googleapis.com/auth/drive",
     ]
 
-    def __init__(self) -> None:
+    def __init__(
+        self, path_credentials: PathType = "", path_token: PathType = ""
+    ) -> None:
         # creds = None
-        path_creds_str = getenv("PATH_CREDS") or ".credentials"
-        path_token_str = getenv("PATH_TOKEN") or ".token"
+        if path_credentials != "":
+            path_creds_str = path_credentials
+        else:
+            path_creds_str = getenv("PATH_CREDS") or ".credentials"
+
+        if path_token != "":
+            path_token_str = path_token
+        else:
+            path_token_str = getenv("PATH_TOKEN") or ".token"
+
         path_creds = Path(path_creds_str)
         path_token = Path(path_token_str)
 
@@ -56,7 +67,9 @@ class Drive:
                 print("21")
 
         else:
-            raise Exception("I need at least token or cred.")
+            raise Exception(
+                "I need a token or a credential. If you don't have, check link"
+            )
 
         if creds.valid:
             try:
@@ -66,6 +79,9 @@ class Drive:
         else:
             raise Exception("can not find valid creds")
 
+    def check_cli(self):
+        print("check cli")
+
     def id_parser(self, url):
         """
         Traverse given directory
